@@ -1,19 +1,18 @@
-import hmac
 import logging
 from functools import wraps
 from typing import Any, Dict, List, Union
 
-import orjson
-import shortuuid
-from django.conf import settings
 from django.db.models import Model
 from django.http import HttpRequest, JsonResponse
 from django.views.decorators.csrf import csrf_protect
 from django.views.decorators.http import require_POST
 
+import orjson
+
+from .call_method_parser import parse_args, parse_call_method_name
 from .components import UnicornField, UnicornView
 from .errors import UnicornViewError
-from .call_method_parser import parse_args, parse_call_method_name
+from .utils import generate_checksum
 
 
 logger = logging.getLogger(__name__)
@@ -183,12 +182,7 @@ class ComponentRequest:
         checksum = self.body.get("checksum")
         assert checksum, "Missing checksum"
 
-        generated_checksum = hmac.new(
-            str.encode(settings.SECRET_KEY),
-            orjson.dumps(self.data),
-            digestmod="sha256",
-        ).hexdigest()
-        generated_checksum = shortuuid.uuid(generated_checksum)[:8]
+        generated_checksum = generate_checksum(orjson.dumps(self.data))
         assert checksum == generated_checksum, "Checksum does not match"
 
 
@@ -252,10 +246,11 @@ def message(request: HttpRequest, component_name: str = None) -> JsonResponse:
                 if hasattr(model_class, "model"):
                     DbModel = model_class.model
 
-                    for m in component.Meta.db_models:
-                        if m.model_class == model_class.model:
-                            db_defaults = m.defaults
-                            break
+                    if hasattr(component, "Meta"):
+                        for m in component.Meta.db_models:
+                            if m.model_class == model_class.model:
+                                db_defaults = m.defaults
+                                break
 
             if not DbModel and db_model_name:
                 assert hasattr(component, "Meta") and hasattr(
